@@ -62,15 +62,12 @@ def test_Interface():
         nif.aggregate_outputs()
     with pytest.raises(NotImplementedError):
         nif._list_outputs()
-    with pytest.raises(NotImplementedError):
-        nif._get_filecopy_info()
 
 
 def test_BaseInterface():
     config.set('monitoring', 'enable', '0')
 
     assert nib.BaseInterface.help() is None
-    assert nib.BaseInterface._get_filecopy_info() == []
 
     class InputSpec(nib.TraitedSpec):
         foo = nib.traits.Int(desc='a random int')
@@ -90,10 +87,6 @@ def test_BaseInterface():
     assert DerivedInterface.help() is None
     assert 'moo' in ''.join(DerivedInterface._inputs_help())
     assert DerivedInterface()._outputs() is None
-    assert DerivedInterface._get_filecopy_info()[0]['key'] == 'woo'
-    assert DerivedInterface._get_filecopy_info()[0]['copy']
-    assert DerivedInterface._get_filecopy_info()[1]['key'] == 'zoo'
-    assert not DerivedInterface._get_filecopy_info()[1]['copy']
     assert DerivedInterface().inputs.foo == nib.Undefined
     with pytest.raises(ValueError):
         DerivedInterface()._check_mandatory_inputs()
