@@ -85,6 +85,8 @@ class DTIFitOutputSpec(TraitedSpec):
               'diffusion weighting'))
     tensor = File(
         exists=True, desc='path/name of file with the 4D tensor volume')
+    sse = File(
+        exists=True, desc='path/name of file with the summed squared error')
 
 
 class DTIFit(FSLCommand):
@@ -111,13 +113,21 @@ class DTIFit(FSLCommand):
     output_spec = DTIFitOutputSpec
 
     def _list_outputs(self):
+        keys_to_ignore = {'outputtype', 'environ', 'args'}
+        # Optional output: Map output name to input flag
+        opt_output = {'tensor': self.inputs.save_tensor,
+                      'sse': self.inputs.sse}
+        # Ignore optional output, whose corresponding input-flag is not defined
+        # or set to False
+        for output, input_flag in opt_output.items():
+            if isdefined(input_flag) and input_flag:
+                # this is wanted output, do not ignore
+                continue
+            keys_to_ignore.add(output)
+
         outputs = self.output_spec().get()
-        for k in list(outputs.keys()):
-            if k not in ('outputtype', 'environ', 'args'):
-                if k != 'tensor' or (isdefined(self.inputs.save_tensor)
-                                     and self.inputs.save_tensor):
-                    outputs[k] = self._gen_fname(
-                        self.inputs.base_name, suffix='_' + k)
+        for k in set(outputs.keys()) - keys_to_ignore:
+            outputs[k] = self._gen_fname(self.inputs.base_name, suffix='_' + k)
         return outputs
 
 
@@ -171,7 +181,7 @@ class FSLXCommandInputSpec(FSLCommandInputSpec):
         low=0,
         value=0,
         usedefault=True,
-        argstr='--burninnoard=%d',
+        argstr='--burnin_noard=%d',
         desc=('num of burnin jumps before the ard is'
               ' imposed'))
     sample_every = traits.Range(
@@ -424,7 +434,7 @@ class BEDPOSTX5(FSLXCommand):
     >>> bedp = fsl.BEDPOSTX5(bvecs='bvecs', bvals='bvals', dwi='diffusion.nii',
     ...                     mask='mask.nii', n_fibres=1)
     >>> bedp.cmdline
-    'bedpostx bedpostx -b 0 --burninnoard=0 --forcedir -n 1 -j 5000 \
+    'bedpostx bedpostx -b 0 --burnin_noard=0 --forcedir -n 1 -j 5000 \
 -s 1 --updateproposalevery=40'
 
     """
